# Bredon


![license](https://img.shields.io/github/license/Innoviox/bredon.svg) [![Build Status](https://travis-ci.org/Innoviox/bredon.svg?branch=master)](https://travis-ci.org/Innoviox/bredon) [![Coverage Status](https://coveralls.io/repos/github/Innoviox/bredon/badge.svg?branch=master)](https://coveralls.io/github/Innoviox/bredon?branch=master) ![GitHub commit activity the past week, 4 weeks, year](https://img.shields.io/github/commit-activity/w/Innoviox/bredon.svg) [![Codacy grade](https://img.shields.io/codacy/grade/6dfcceeaa3cc48b19d784e86c2072fa6.svg)
](https://app.codacy.com/app/Innoviox/bredon/dashboard) ![Issue Stats](https://img.shields.io/badge/issues%20closed%20in-1%20day-green.svg?style=flat) [![CodeFactor](https://www.codefactor.io/repository/github/innoviox/bredon/badge)](https://www.codefactor.io/repository/github/innoviox/bredon)

UI and AI for the game Tak in python.

## Local installation
 - `git clone https://github.com/Innoviox/bredon.git`
 - `cd bredon`
 - `pip install -r requirements.txt`

## System installation
 - `pip3 install bredon`
